@@ -113,7 +113,7 @@ class BinanceLocalDepthCacheManager(threading.Thread):
                  ubwa_manager: Optional[Union[BinanceWebSocketApiManager, bool]] = False,
                  warn_on_update: bool = True):
         super().__init__()
-        self.version = "0.7.2"
+        self.version = "0.7.3"
         self.name = "unicorn-binance-local-depth-cache"
         logger.info(f"New instance of {self.get_user_agent()} on "
                     f"{str(platform.system())} {str(platform.release())} for exchange {exchange} started ...")
@@ -323,7 +323,11 @@ class BinanceLocalDepthCacheManager(threading.Thread):
         self._reset_depth_cache(market=market)
         self.depth_caches[market]['last_refresh_time'] = int(time.time())
         self.depth_caches[market]['last_update_time'] = int(time.time())
-        self.depth_caches[market]['last_update_id'] = int(order_book['lastUpdateId'])
+        try:
+            self.depth_caches[market]['last_update_id'] = int(order_book['lastUpdateId'])
+        except TypeError as error_msg:
+            logger.error(f"BinanceLocalDepthCacheManager._init_depth_cache() - TypeError - error_msg: {error_msg}")
+            return False
         self._apply_updates(order_book, market=market)
         for bid in order_book['bids']:
             self._add_bid(bid, market=market)
